Index: zaptel.c
===================================================================
--- zaptel.c	(revision 1051)
+++ zaptel.c	(working copy)
@@ -1321,6 +1321,27 @@
 	return 0;
 }
 
+#ifdef LINUX26
+static int zt_register_hdlc_device(struct net_device *dev, const char *dev_name)
+{
+	int result;
+	if(dev_name && strlen(dev_name)) {
+
+		result = dev_alloc_name(dev, dev_name);
+		if (result < 0)
+			return result;
+	}
+	result = register_netdev(dev);
+	if (result != 0)
+		return -EIO;
+#if LINUX_VERSION_CODE <= KERNEL_VERSION(2,6,14)
+	if (netif_carrier_ok(dev))
+		netif_carrier_off(dev); /* no carrier until DCD goes up */
+#endif
+	return 0;
+}
+#endif
+
 #ifdef NEW_HDLC_INTERFACE
 static int zt_net_stop(struct net_device *dev)
 {
@@ -3345,7 +3366,7 @@
 					dev_to_hdlc(chans[ch.chan]->hdlcnetdev->netdev)->xmit = zt_xmit;
 					spin_unlock_irqrestore(&chans[ch.chan]->lock, flags);
 					/* Briefly restore interrupts while we register the device */
-					res = register_hdlc_device(chans[ch.chan]->hdlcnetdev->netdev);
+					res = zt_register_hdlc_device(chans[ch.chan]->hdlcnetdev->netdev, ch.netdev_name);
 					spin_lock_irqsave(&chans[ch.chan]->lock, flags);
 				} else {
 					printk("Unable to allocate hdlc: *shrug*\n");
Index: zaptel.h
===================================================================
--- zaptel.h	(revision 1051)
+++ zaptel.h	(working copy)
@@ -105,7 +105,7 @@
 
 #define __ZT_SIG_DACS	 (1 << 16)
 
-#define ZT_SIG_CLEAR	 (1 << 7)					/* Clear channel */
+#define ZT_SIG_CLEAR	 (1 << 7)			/* Clear channel */
 #define ZT_SIG_HDLCRAW	((1 << 8)  | ZT_SIG_CLEAR)	/* Raw unchecked HDLC */
 #define ZT_SIG_HDLCFCS	((1 << 9)  | ZT_SIG_HDLCRAW)	/* HDLC with FCS calculation */
 #define ZT_SIG_HDLCNET	((1 << 10) | ZT_SIG_HDLCFCS)	/* HDLC Network */
@@ -238,7 +238,8 @@
 int	deflaw;		/* Default law (ZT_LAW_DEFAULT, ZT_LAW_MULAW, or ZT_LAW_ALAW */
 int	master;		/* Master channel if sigtype is ZT_SLAVE */
 int	idlebits;	/* Idle bits (if this is a CAS channel) or
-			   channel to monitor (if this is DACS channel) */
+                          channel to monitor (if this is DACS channel) */
+char netdev_name[16]; /*name for the hdlc network device*/
 } ZT_CHANCONFIG;
 
 typedef struct zt_sfconfig
Index: zaptel.conf.sample
===================================================================
--- zaptel.conf.sample	(revision 1051)
+++ zaptel.conf.sample	(working copy)
@@ -105,7 +105,13 @@
 #             hardware.
 # "nethdlc" : The zaptel driver bundles the channels together into an
 #             hdlc network device, which in turn can be configured with
-#             sethdlc (available separately).
+#             sethdlc (available separately). In 2.6.x kernels you can also optionally
+#	       pass the name for the network interface after the channel list.
+#	        Syntax:
+#               nethdlc=<channel list>[:interface name]
+#	      Use original names, don't use the names which have been already registered 
+#	      in system e.g eth.
+#             
 # "dacs"    : The zaptel driver cross connects the channels starting at
 #             the channel number listed at the end, after a colon
 # "dacsrbs" : The zaptel driver cross connects the channels starting at
Index: ztcfg.c
===================================================================
--- ztcfg.c	(revision 1051)
+++ ztcfg.c	(working copy)
@@ -557,6 +557,11 @@
 					cc[x].master = master;
 				} else {
 					cc[x].sigtype = ZT_SIG_HDLCNET;
+					cc[x].netdev_name[0]='\0';
+					if(idle) {
+					    strncpy(cc[x].netdev_name, idle, sizeof(cc[x].netdev_name));
+					    cc[x].netdev_name[sizeof(cc[x].netdev_name)-1] = '\0';
+					}
 					master = x;
 				}
 			} else if (!strcasecmp(keyword, "fcshdlc")) {
